Documentation
¶
Index ¶
- Variables
- func FinalizeNats(subscriptions *[]*nats.Subscription) error
- func FinalizeStan(subscriptions *[]stan.Subscription) error
- func SetupNats(host string, port int, user string, pass string, ...) error
- func SetupNatsWithCreds(host string, port int, credsFile string, closeHandler *grawt.CloseHandler) error
- func SetupStan(clusterName string, clientId string, host string, port int, user string, ...) (err error)
Constants ¶
This section is empty.
Variables ¶
var ( NatsClient *nats.Conn StanClient stan.Conn )
Functions ¶
func FinalizeNats ¶ added in v0.0.2
func FinalizeNats(subscriptions *[]*nats.Subscription) error
func FinalizeStan ¶
func FinalizeStan(subscriptions *[]stan.Subscription) error
func SetupNatsWithCreds ¶ added in v0.1.2
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.