Documentation
¶
Index ¶
- Variables
- func FinalizeNats(subscriptions *[]*NatsSubscription) error
- func FinalizeStan(subscriptions *[]Subscription) error
- func SetupNats(host string, port int, user string, pass string, ...) error
- func SetupStan(clusterName string, clientId string, host string, port int, user string, ...) (err error)
- type Msg
- type NatsMsg
- type NatsSubscription
- type Subscription
Constants ¶
This section is empty.
Variables ¶
var ( NatsClient *nats.Conn StanClient stan.Conn )
Functions ¶
func FinalizeNats ¶ added in v0.0.2
func FinalizeNats(subscriptions *[]*NatsSubscription) error
func FinalizeStan ¶
func FinalizeStan(subscriptions *[]Subscription) error
Types ¶
type NatsSubscription ¶ added in v0.0.2
type NatsSubscription = nats.Subscription
type Subscription ¶
type Subscription = stan.Subscription
Click to show internal directories.
Click to hide internal directories.