nacl

package module
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2020 License: MIT Imports: 5 Imported by: 0

README

nacl

Client helper for NATS/STAN

Documentation

Index

Constants

This section is empty.

Variables

var (
	NatsClient *nats.Conn
	StanClient stan.Conn
)

Functions

func FinalizeNats added in v0.0.2

func FinalizeNats(subscriptions *[]*NatsSubscription) error

func FinalizeStan

func FinalizeStan(subscriptions *[]Subscription) error

func SetupNats

func SetupNats(host string, port int, user string, pass string, closeHandler *grawt.CloseHandler) error

func SetupStan

func SetupStan(clusterName string, clientId string, host string, port int, user string, pass string, closeHandler *grawt.CloseHandler) (err error)

Types

type Msg

type Msg = stan.Msg

type NatsMsg

type NatsMsg = nats.Msg

type NatsSubscription added in v0.0.2

type NatsSubscription = nats.Subscription

type Subscription

type Subscription = stan.Subscription

Jump to